# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.projects_api import ProjectsApi  # noqa: E501
from phrase_api.rest import ApiException


class TestProjectsApi(unittest.TestCase):
    """ProjectsApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.projects_api.ProjectsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_project_create(self):
        """Test case for project_create

        Create a project  # noqa: E501
        """
        pass

    def test_project_delete(self):
        """Test case for project_delete

        Delete a project  # noqa: E501
        """
        pass

    def test_project_show(self):
        """Test case for project_show

        Get a single project  # noqa: E501
        """
        pass

    def test_project_update(self):
        """Test case for project_update

        Update a project  # noqa: E501
        """
        pass

    def test_projects_list(self):
        """Test case for projects_list

        List projects  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class Webhook(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'callback_url': 'str',
        'description': 'str',
        'events': 'list[str]',
        'active': 'bool',
        'include_branches': 'bool',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'callback_url': 'callback_url',
        'description': 'description',
        'events': 'events',
        'active': 'active',
        'include_branches': 'include_branches',
        'created_at': 'created_at',
        'updated_at': 'updated_at'
    }

    def __init__(self, id=None, callback_url=None, description=None, events=None, active=None, include_branches=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """Webhook - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._callback_url = None
        self._description = None
        self._events = None
        self._active = None
        self._include_branches = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if callback_url is not None:
            self.callback_url = callback_url
        if description is not None:
            self.description = description
        if events is not None:
            self.events = events
        if active is not None:
            self.active = active
        if include_branches is not None:
            self.include_branches = include_branches
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this Webhook.  # noqa: E501


        :return: The id of this Webhook.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Webhook.


        :param id: The id of this Webhook.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def callback_url(self):
        """Gets the callback_url of this Webhook.  # noqa: E501


        :return: The callback_url of this Webhook.  # noqa: E501
        :rtype: str
        """
        return self._callback_url

    @callback_url.setter
    def callback_url(self, callback_url):
        """Sets the callback_url of this Webhook.


        :param callback_url: The callback_url of this Webhook.  # noqa: E501
        :type: str
        """

        self._callback_url = callback_url

    @property
    def description(self):
        """Gets the description of this Webhook.  # noqa: E501


        :return: The description of this Webhook.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Webhook.


        :param description: The description of this Webhook.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def events(self):
        """Gets the events of this Webhook.  # noqa: E501


        :return: The events of this Webhook.  # noqa: E501
        :rtype: list[str]
        """
        return self._events

    @events.setter
    def events(self, events):
        """Sets the events of this Webhook.


        :param events: The events of this Webhook.  # noqa: E501
        :type: list[str]
        """

        self._events = events

    @property
    def active(self):
        """Gets the active of this Webhook.  # noqa: E501


        :return: The active of this Webhook.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this Webhook.


        :param active: The active of this Webhook.  # noqa: E501
        :type: bool
        """

        self._active = active

    @property
    def include_branches(self):
        """Gets the include_branches of this Webhook.  # noqa: E501


        :return: The include_branches of this Webhook.  # noqa: E501
        :rtype: bool
        """
        return self._include_branches

    @include_branches.setter
    def include_branches(self, include_branches):
        """Sets the include_branches of this Webhook.


        :param include_branches: The include_branches of this Webhook.  # noqa: E501
        :type: bool
        """

        self._include_branches = include_branches

    @property
    def created_at(self):
        """Gets the created_at of this Webhook.  # noqa: E501


        :return: The created_at of this Webhook.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Webhook.


        :param created_at: The created_at of this Webhook.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this Webhook.  # noqa: E501


        :return: The updated_at of this Webhook.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this Webhook.


        :param updated_at: The updated_at of this Webhook.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Webhook):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Webhook):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import phrase_api
from phrase_api.models.glossary_create_parameters import GlossaryCreateParameters  # noqa: E501
from phrase_api.rest import ApiException

class TestGlossaryCreateParameters(unittest.TestCase):
    """GlossaryCreateParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test GlossaryCreateParameters
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = phrase_api.models.glossary_create_parameters.GlossaryCreateParameters()  # noqa: E501
        if include_optional :
            return GlossaryCreateParameters(
                name = 'My glossary', 
                project_ids = 'abcd1234abcd1234abcd1234,abcd1234abcd1234abcd1235', 
                space_ids = ["abcd1234abcd1234abcd1234","abcd1234abcd1234abcd1235"]
            )
        else :
            return GlossaryCreateParameters(
        )

    def testGlossaryCreateParameters(self):
        """Test GlossaryCreateParameters"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import phrase_api
from phrase_api.models.upload_summary import UploadSummary  # noqa: E501
from phrase_api.rest import ApiException

class TestUploadSummary(unittest.TestCase):
    """UploadSummary unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test UploadSummary
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = phrase_api.models.upload_summary.UploadSummary()  # noqa: E501
        if include_optional :
            return UploadSummary(
                locales_created = 56, 
                translation_keys_created = 56, 
                translation_keys_updated = 56, 
                translation_keys_unmentioned = 56, 
                translations_created = 56, 
                translations_updated = 56, 
                tags_created = 56, 
                translation_keys_ignored = 56
            )
        else :
            return UploadSummary(
        )

    def testUploadSummary(self):
        """Test UploadSummary"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class JobTemplateLocaleUpdateParameters(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'branch': 'str',
        'locale_id': 'str',
        'user_ids': 'list[str]',
        'reviewer_ids': 'list[str]'
    }

    attribute_map = {
        'branch': 'branch',
        'locale_id': 'locale_id',
        'user_ids': 'user_ids',
        'reviewer_ids': 'reviewer_ids'
    }

    def __init__(self, branch=None, locale_id=None, user_ids=None, reviewer_ids=None, local_vars_configuration=None):  # noqa: E501
        """JobTemplateLocaleUpdateParameters - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._branch = None
        self._locale_id = None
        self._user_ids = None
        self._reviewer_ids = None
        self.discriminator = None

        if branch is not None:
            self.branch = branch
        self.locale_id = locale_id
        if user_ids is not None:
            self.user_ids = user_ids
        if reviewer_ids is not None:
            self.reviewer_ids = reviewer_ids

    @property
    def branch(self):
        """Gets the branch of this JobTemplateLocaleUpdateParameters.  # noqa: E501

        specify the branch to use  # noqa: E501

        :return: The branch of this JobTemplateLocaleUpdateParameters.  # noqa: E501
        :rtype: str
        """
        return self._branch

    @branch.setter
    def branch(self, branch):
        """Sets the branch of this JobTemplateLocaleUpdateParameters.

        specify the branch to use  # noqa: E501

        :param branch: The branch of this JobTemplateLocaleUpdateParameters.  # noqa: E501
        :type: str
        """

        self._branch = branch

    @property
    def locale_id(self):
        """Gets the locale_id of this JobTemplateLocaleUpdateParameters.  # noqa: E501

        locale id  # noqa: E501

        :return: The locale_id of this JobTemplateLocaleUpdateParameters.  # noqa: E501
        :rtype: str
        """
        return self._locale_id

    @locale_id.setter
    def locale_id(self, locale_id):
        """Sets the locale_id of this JobTemplateLocaleUpdateParameters.

        locale id  # noqa: E501

        :param locale_id: The locale_id of this JobTemplateLocaleUpdateParameters.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and locale_id is None:  # noqa: E501
            raise ValueError("Invalid value for `locale_id`, must not be `None`")  # noqa: E501

        self._locale_id = locale_id

    @property
    def user_ids(self):
        """Gets the user_ids of this JobTemplateLocaleUpdateParameters.  # noqa: E501

        Array of user ids to be assigned to the job template locale  # noqa: E501

        :return: The user_ids of this JobTemplateLocaleUpdateParameters.  # noqa: E501
        :rtype: list[str]
        """
        return self._user_ids

    @user_ids.setter
    def user_ids(self, user_ids):
        """Sets the user_ids of this JobTemplateLocaleUpdateParameters.

        Array of user ids to be assigned to the job template locale  # noqa: E501

        :param user_ids: The user_ids of this JobTemplateLocaleUpdateParameters.  # noqa: E501
        :type: list[str]
        """

        self._user_ids = user_ids

    @property
    def reviewer_ids(self):
        """Gets the reviewer_ids of this JobTemplateLocaleUpdateParameters.  # noqa: E501

        Array of reviewer ids to be assigned to the job template locale  # noqa: E501

        :return: The reviewer_ids of this JobTemplateLocaleUpdateParameters.  # noqa: E501
        :rtype: list[str]
        """
        return self._reviewer_ids

    @reviewer_ids.setter
    def reviewer_ids(self, reviewer_ids):
        """Sets the reviewer_ids of this JobTemplateLocaleUpdateParameters.

        Array of reviewer ids to be assigned to the job template locale  # noqa: E501

        :param reviewer_ids: The reviewer_ids of this JobTemplateLocaleUpdateParameters.  # noqa: E501
        :type: list[str]
        """

        self._reviewer_ids = reviewer_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobTemplateLocaleUpdateParameters):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, JobTemplateLocaleUpdateParameters):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class ScreenshotMarkerCreateParameters(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'branch': 'str',
        'key_id': 'str',
        'presentation': 'str'
    }

    attribute_map = {
        'branch': 'branch',
        'key_id': 'key_id',
        'presentation': 'presentation'
    }

    def __init__(self, branch=None, key_id=None, presentation=None, local_vars_configuration=None):  # noqa: E501
        """ScreenshotMarkerCreateParameters - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._branch = None
        self._key_id = None
        self._presentation = None
        self.discriminator = None

        if branch is not None:
            self.branch = branch
        if key_id is not None:
            self.key_id = key_id
        if presentation is not None:
            self.presentation = presentation

    @property
    def branch(self):
        """Gets the branch of this ScreenshotMarkerCreateParameters.  # noqa: E501

        specify the branch to use  # noqa: E501

        :return: The branch of this ScreenshotMarkerCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._branch

    @branch.setter
    def branch(self, branch):
        """Sets the branch of this ScreenshotMarkerCreateParameters.

        specify the branch to use  # noqa: E501

        :param branch: The branch of this ScreenshotMarkerCreateParameters.  # noqa: E501
        :type: str
        """

        self._branch = branch

    @property
    def key_id(self):
        """Gets the key_id of this ScreenshotMarkerCreateParameters.  # noqa: E501

        Specify the Key ID which should be highlighted on the specified screenshot. The Key must belong to the project.  # noqa: E501

        :return: The key_id of this ScreenshotMarkerCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._key_id

    @key_id.setter
    def key_id(self, key_id):
        """Sets the key_id of this ScreenshotMarkerCreateParameters.

        Specify the Key ID which should be highlighted on the specified screenshot. The Key must belong to the project.  # noqa: E501

        :param key_id: The key_id of this ScreenshotMarkerCreateParameters.  # noqa: E501
        :type: str
        """

        self._key_id = key_id

    @property
    def presentation(self):
        """Gets the presentation of this ScreenshotMarkerCreateParameters.  # noqa: E501

        Presentation details of the screenshot marker in JSON format.<br/><br/>Each Screenshot Marker is represented as a rectangular shaped highlight box with the name of the specified Key attached. You can specify the marker position on the screenshot (<code>x</code>-axis and <code>y</code>-axis in pixels) from the top left corner of the screenshot and the dimensions of the marker itself (<code>w</code> and <code>h</code> in pixels).  # noqa: E501

        :return: The presentation of this ScreenshotMarkerCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._presentation

    @presentation.setter
    def presentation(self, presentation):
        """Sets the presentation of this ScreenshotMarkerCreateParameters.

        Presentation details of the screenshot marker in JSON format.<br/><br/>Each Screenshot Marker is represented as a rectangular shaped highlight box with the name of the specified Key attached. You can specify the marker position on the screenshot (<code>x</code>-axis and <code>y</code>-axis in pixels) from the top left corner of the screenshot and the dimensions of the marker itself (<code>w</code> and <code>h</code> in pixels).  # noqa: E501

        :param presentation: The presentation of this ScreenshotMarkerCreateParameters.  # noqa: E501
        :type: str
        """

        self._presentation = presentation

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ScreenshotMarkerCreateParameters):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ScreenshotMarkerCreateParameters):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class Upload(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'filename': 'str',
        'format': 'str',
        'state': 'str',
        'tag': 'str',
        'summary': 'UploadSummary',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'filename': 'filename',
        'format': 'format',
        'state': 'state',
        'tag': 'tag',
        'summary': 'summary',
        'created_at': 'created_at',
        'updated_at': 'updated_at'
    }

    def __init__(self, id=None, filename=None, format=None, state=None, tag=None, summary=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """Upload - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._filename = None
        self._format = None
        self._state = None
        self._tag = None
        self._summary = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if filename is not None:
            self.filename = filename
        if format is not None:
            self.format = format
        if state is not None:
            self.state = state
        if tag is not None:
            self.tag = tag
        if summary is not None:
            self.summary = summary
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this Upload.  # noqa: E501


        :return: The id of this Upload.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Upload.


        :param id: The id of this Upload.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def filename(self):
        """Gets the filename of this Upload.  # noqa: E501


        :return: The filename of this Upload.  # noqa: E501
        :rtype: str
        """
        return self._filename

    @filename.setter
    def filename(self, filename):
        """Sets the filename of this Upload.


        :param filename: The filename of this Upload.  # noqa: E501
        :type: str
        """

        self._filename = filename

    @property
    def format(self):
        """Gets the format of this Upload.  # noqa: E501


        :return: The format of this Upload.  # noqa: E501
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this Upload.


        :param format: The format of this Upload.  # noqa: E501
        :type: str
        """

        self._format = format

    @property
    def state(self):
        """Gets the state of this Upload.  # noqa: E501


        :return: The state of this Upload.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this Upload.


        :param state: The state of this Upload.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def tag(self):
        """Gets the tag of this Upload.  # noqa: E501


        :return: The tag of this Upload.  # noqa: E501
        :rtype: str
        """
        return self._tag

    @tag.setter
    def tag(self, tag):
        """Sets the tag of this Upload.


        :param tag: The tag of this Upload.  # noqa: E501
        :type: str
        """

        self._tag = tag

    @property
    def summary(self):
        """Gets the summary of this Upload.  # noqa: E501


        :return: The summary of this Upload.  # noqa: E501
        :rtype: UploadSummary
        """
        return self._summary

    @summary.setter
    def summary(self, summary):
        """Sets the summary of this Upload.


        :param summary: The summary of this Upload.  # noqa: E501
        :type: UploadSummary
        """

        self._summary = summary

    @property
    def created_at(self):
        """Gets the created_at of this Upload.  # noqa: E501


        :return: The created_at of this Upload.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Upload.


        :param created_at: The created_at of this Upload.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this Upload.  # noqa: E501


        :return: The updated_at of this Upload.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this Upload.


        :param updated_at: The updated_at of this Upload.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Upload):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Upload):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class WebhookDelivery(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'webhook_id': 'str',
        'response_status_code': 'int',
        'delivered_at': 'datetime',
        'duration_ms': 'int',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'webhook_id': 'webhook_id',
        'response_status_code': 'response_status_code',
        'delivered_at': 'delivered_at',
        'duration_ms': 'duration_ms',
        'created_at': 'created_at',
        'updated_at': 'updated_at'
    }

    def __init__(self, id=None, webhook_id=None, response_status_code=None, delivered_at=None, duration_ms=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """WebhookDelivery - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._webhook_id = None
        self._response_status_code = None
        self._delivered_at = None
        self._duration_ms = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if webhook_id is not None:
            self.webhook_id = webhook_id
        if response_status_code is not None:
            self.response_status_code = response_status_code
        if delivered_at is not None:
            self.delivered_at = delivered_at
        if duration_ms is not None:
            self.duration_ms = duration_ms
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this WebhookDelivery.  # noqa: E501


        :return: The id of this WebhookDelivery.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this WebhookDelivery.


        :param id: The id of this WebhookDelivery.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def webhook_id(self):
        """Gets the webhook_id of this WebhookDelivery.  # noqa: E501


        :return: The webhook_id of this WebhookDelivery.  # noqa: E501
        :rtype: str
        """
        return self._webhook_id

    @webhook_id.setter
    def webhook_id(self, webhook_id):
        """Sets the webhook_id of this WebhookDelivery.


        :param webhook_id: The webhook_id of this WebhookDelivery.  # noqa: E501
        :type: str
        """

        self._webhook_id = webhook_id

    @property
    def response_status_code(self):
        """Gets the response_status_code of this WebhookDelivery.  # noqa: E501


        :return: The response_status_code of this WebhookDelivery.  # noqa: E501
        :rtype: int
        """
        return self._response_status_code

    @response_status_code.setter
    def response_status_code(self, response_status_code):
        """Sets the response_status_code of this WebhookDelivery.


        :param response_status_code: The response_status_code of this WebhookDelivery.  # noqa: E501
        :type: int
        """

        self._response_status_code = response_status_code

    @property
    def delivered_at(self):
        """Gets the delivered_at of this WebhookDelivery.  # noqa: E501


        :return: The delivered_at of this WebhookDelivery.  # noqa: E501
        :rtype: datetime
        """
        return self._delivered_at

    @delivered_at.setter
    def delivered_at(self, delivered_at):
        """Sets the delivered_at of this WebhookDelivery.


        :param delivered_at: The delivered_at of this WebhookDelivery.  # noqa: E501
        :type: datetime
        """

        self._delivered_at = delivered_at

    @property
    def duration_ms(self):
        """Gets the duration_ms of this WebhookDelivery.  # noqa: E501


        :return: The duration_ms of this WebhookDelivery.  # noqa: E501
        :rtype: int
        """
        return self._duration_ms

    @duration_ms.setter
    def duration_ms(self, duration_ms):
        """Sets the duration_ms of this WebhookDelivery.


        :param duration_ms: The duration_ms of this WebhookDelivery.  # noqa: E501
        :type: int
        """

        self._duration_ms = duration_ms

    @property
    def created_at(self):
        """Gets the created_at of this WebhookDelivery.  # noqa: E501


        :return: The created_at of this WebhookDelivery.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this WebhookDelivery.


        :param created_at: The created_at of this WebhookDelivery.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this WebhookDelivery.  # noqa: E501


        :return: The updated_at of this WebhookDelivery.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this WebhookDelivery.


        :param updated_at: The updated_at of this WebhookDelivery.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebhookDelivery):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WebhookDelivery):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.uploads_api import UploadsApi  # noqa: E501
from phrase_api.rest import ApiException


class TestUploadsApi(unittest.TestCase):
    """UploadsApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.uploads_api.UploadsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_upload_create(self):
        """Test case for upload_create

        Upload a new file  # noqa: E501
        """
        pass

    def test_upload_show(self):
        """Test case for upload_show

        View upload details  # noqa: E501
        """
        pass

    def test_uploads_list(self):
        """Test case for uploads_list

        List uploads  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from phrase_api.api_client import ApiClient
from phrase_api.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class GitLabSyncApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def gitlab_sync_delete(self, id, **kwargs):  # noqa: E501
        """Delete single Sync Setting  # noqa: E501

        Deletes a single GitLab Sync Setting.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.gitlab_sync_delete(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str account_id: Account ID to specify the actual account the GitLab Sync should be created in. Required if the requesting user is a member of multiple accounts.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.gitlab_sync_delete_with_http_info(id, **kwargs)  # noqa: E501

    def gitlab_sync_delete_with_http_info(self, id, **kwargs):  # noqa: E501
        """Delete single Sync Setting  # noqa: E501

        Deletes a single GitLab Sync Setting.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.gitlab_sync_delete_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str account_id: Account ID to specify the actual account the GitLab Sync should be created in. Required if the requesting user is a member of multiple accounts.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id',
            'x_phrase_app_otp',
            'account_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method gitlab_sync_delete" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `gitlab_sync_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []
        if 'account_id' in local_var_params and local_var_params['account_id'] is not None:  # noqa: E501
            query_params.append(('account_id', local_var_params['account_id']))  # noqa: E501

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/gitlab_syncs/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def gitlab_sync_export(self, gitlab_sync_id, gitlab_sync_export_parameters, **kwargs):  # noqa: E501
        """Export from Phrase Strings to GitLab  # noqa: E501

        Export translations from Phrase Strings to GitLab according to the .phraseapp.yml file within the GitLab repository.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.gitlab_sync_export(gitlab_sync_id, gitlab_sync_export_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str gitlab_sync_id: Gitlab Sync ID (required)
        :param GitlabSyncExportParameters gitlab_sync_export_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: GitlabSyncExport
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.gitlab_sync_export_with_http_info(gitlab_sync_id, gitlab_sync_export_parameters, **kwargs)  # noqa: E501

    def gitlab_sync_export_with_http_info(self, gitlab_sync_id, gitlab_sync_export_parameters, **kwargs):  # noqa: E501
        """Export from Phrase Strings to GitLab  # noqa: E501

        Export translations from Phrase Strings to GitLab according to the .phraseapp.yml file within the GitLab repository.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.gitlab_sync_export_with_http_info(gitlab_sync_id, gitlab_sync_export_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str gitlab_sync_id: Gitlab Sync ID (required)
        :param GitlabSyncExportParameters gitlab_sync_export_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(GitlabSyncExport, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'gitlab_sync_id',
            'gitlab_sync_export_parameters',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method gitlab_sync_export" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'gitlab_sync_id' is set
        if self.api_client.client_side_validation and ('gitlab_sync_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['gitlab_sync_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `gitlab_sync_id` when calling `gitlab_sync_export`")  # noqa: E501
        # verify the required parameter 'gitlab_sync_export_parameters' is set
        if self.api_client.client_side_validation and ('gitlab_sync_export_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['gitlab_sync_export_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `gitlab_sync_export_parameters` when calling `gitlab_sync_export`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'gitlab_sync_id' in local_var_params:
            path_params['gitlab_sync_id'] = local_var_params['gitlab_sync_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'gitlab_sync_export_parameters' in local_var_params:
            body_params = local_var_params['gitlab_sync_export_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/gitlab_syncs/{gitlab_sync_id}/export', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GitlabSyncExport',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def gitlab_sync_history(self, gitlab_sync_id, **kwargs):  # noqa: E501
        """History of single Sync Setting  # noqa: E501

        List history for a single Sync Setting.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.gitlab_sync_history(gitlab_sync_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str gitlab_sync_id: Gitlab Sync ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param int page: Page number
        :param int per_page: allows you to specify a page size up to 100 items, 25 by default
        :param str account_id: Account ID to specify the actual account the GitLab Sync should be created in. Required if the requesting user is a member of multiple accounts.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[GitlabSyncHistory]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.gitlab_sync_history_with_http_info(gitlab_sync_id, **kwargs)  # noqa: E501

    def gitlab_sync_history_with_http_info(self, gitlab_sync_id, **kwargs):  # noqa: E501
        """History of single Sync Setting  # noqa: E501

        List history for a single Sync Setting.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.gitlab_sync_history_with_http_info(gitlab_sync_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str gitlab_sync_id: Gitlab Sync ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param int page: Page number
        :param int per_page: allows you to specify a page size up to 100 items, 25 by default
        :param str account_id: Account ID to specify the actual account the GitLab Sync should be created in. Required if the requesting user is a member of multiple accounts.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[GitlabSyncHistory], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'gitlab_sync_id',
            'x_phrase_app_otp',
            'page',
            'per_page',
            'account_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method gitlab_sync_history" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'gitlab_sync_id' is set
        if self.api_client.client_side_validation and ('gitlab_sync_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['gitlab_sync_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `gitlab_sync_id` when calling `gitlab_sync_history`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'gitlab_sync_id' in local_var_params:
            path_params['gitlab_sync_id'] = local_var_params['gitlab_sync_id']  # noqa: E501

        query_params = []
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501
        if 'per_page' in local_var_params and local_var_params['per_page'] is not None:  # noqa: E501
            query_params.append(('per_page', local_var_params['per_page']))  # noqa: E501
        if 'account_id' in local_var_params and local_var_params['account_id'] is not None:  # noqa: E501
            query_params.append(('account_id', local_var_params['account_id']))  # noqa: E501

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/gitlab_syncs/{gitlab_sync_id}/history', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[GitlabSyncHistory]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def gitlab_sync_import(self, gitlab_sync_id, gitlab_sync_import_parameters, **kwargs):  # noqa: E501
        """Import from GitLab to Phrase  # noqa: E501

        Import translations from GitLab to Phrase Strings according to the .phraseapp.yml file within the GitLab repository.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.gitlab_sync_import(gitlab_sync_id, gitlab_sync_import_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str gitlab_sync_id: Gitlab Sync ID (required)
        :param GitlabSyncImportParameters gitlab_sync_import_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[Upload]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.gitlab_sync_import_with_http_info(gitlab_sync_id, gitlab_sync_import_parameters, **kwargs)  # noqa: E501

    def gitlab_sync_import_with_http_info(self, gitlab_sync_id, gitlab_sync_import_parameters, **kwargs):  # noqa: E501
        """Import from GitLab to Phrase  # noqa: E501

        Import translations from GitLab to Phrase Strings according to the .phraseapp.yml file within the GitLab repository.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.gitlab_sync_import_with_http_info(gitlab_sync_id, gitlab_sync_import_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str gitlab_sync_id: Gitlab Sync ID (required)
        :param GitlabSyncImportParameters gitlab_sync_import_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[Upload], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'gitlab_sync_id',
            'gitlab_sync_import_parameters',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method gitlab_sync_import" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'gitlab_sync_id' is set
        if self.api_client.client_side_validation and ('gitlab_sync_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['gitlab_sync_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `gitlab_sync_id` when calling `gitlab_sync_import`")  # noqa: E501
        # verify the required parameter 'gitlab_sync_import_parameters' is set
        if self.api_client.client_side_validation and ('gitlab_sync_import_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['gitlab_sync_import_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `gitlab_sync_import_parameters` when calling `gitlab_sync_import`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'gitlab_sync_id' in local_var_params:
            path_params['gitlab_sync_id'] = local_var_params['gitlab_sync_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'gitlab_sync_import_parameters' in local_var_params:
            body_params = local_var_params['gitlab_sync_import_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/gitlab_syncs/{gitlab_sync_id}/import', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Upload]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def gitlab_sync_list(self, **kwargs):  # noqa: E501
        """List GitLab syncs  # noqa: E501

        List all GitLab Sync Settings for which synchronisation with Phrase Strings and GitLab is activated.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.gitlab_sync_list(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str account_id: Account ID to specify the actual account the GitLab Sync should be created in. Required if the requesting user is a member of multiple accounts.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[GitlabSync]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.gitlab_sync_list_with_http_info(**kwargs)  # noqa: E501

    def gitlab_sync_list_with_http_info(self, **kwargs):  # noqa: E501
        """List GitLab syncs  # noqa: E501

        List all GitLab Sync Settings for which synchronisation with Phrase Strings and GitLab is activated.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.gitlab_sync_list_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str account_id: Account ID to specify the actual account the GitLab Sync should be created in. Required if the requesting user is a member of multiple accounts.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[GitlabSync], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'x_phrase_app_otp',
            'account_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method gitlab_sync_list" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'account_id' in local_var_params and local_var_params['account_id'] is not None:  # noqa: E501
            query_params.append(('account_id', local_var_params['account_id']))  # noqa: E501

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/gitlab_syncs', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[GitlabSync]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def gitlab_sync_show(self, id, **kwargs):  # noqa: E501
        """Get single Sync Setting  # noqa: E501

        Shows a single GitLab Sync Setting.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.gitlab_sync_show(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str account_id: Account ID to specify the actual account the GitLab Sync should be created in. Required if the requesting user is a member of multiple accounts.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: GitlabSync
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.gitlab_sync_show_with_http_info(id, **kwargs)  # noqa: E501

    def gitlab_sync_show_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get single Sync Setting  # noqa: E501

        Shows a single GitLab Sync Setting.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.gitlab_sync_show_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str account_id: Account ID to specify the actual account the GitLab Sync should be created in. Required if the requesting user is a member of multiple accounts.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(GitlabSync, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id',
            'x_phrase_app_otp',
            'account_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method gitlab_sync_show" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `gitlab_sync_show`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []
        if 'account_id' in local_var_params and local_var_params['account_id'] is not None:  # noqa: E501
            query_params.append(('account_id', local_var_params['account_id']))  # noqa: E501

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/gitlab_syncs/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GitlabSync',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def gitlab_sync_update(self, id, **kwargs):  # noqa: E501
        """Update single Sync Setting  # noqa: E501

        Updates a single GitLab Sync Setting.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.gitlab_sync_update(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str account_id: Account ID to specify the actual account the GitLab Sync should be created in. Required if the requesting user is a member of multiple accounts.
        :param str phrase_project_code: Code of the related Phrase Strings Project.
        :param int gitlab_project_id: ID of the related GitLab Project.
        :param str gitlab_branch_name: Name of the GitLab Branch.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: GitlabSync
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.gitlab_sync_update_with_http_info(id, **kwargs)  # noqa: E501

    def gitlab_sync_update_with_http_info(self, id, **kwargs):  # noqa: E501
        """Update single Sync Setting  # noqa: E501

        Updates a single GitLab Sync Setting.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.gitlab_sync_update_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str account_id: Account ID to specify the actual account the GitLab Sync should be created in. Required if the requesting user is a member of multiple accounts.
        :param str phrase_project_code: Code of the related Phrase Strings Project.
        :param int gitlab_project_id: ID of the related GitLab Project.
        :param str gitlab_branch_name: Name of the GitLab Branch.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(GitlabSync, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id',
            'x_phrase_app_otp',
            'account_id',
            'phrase_project_code',
            'gitlab_project_id',
            'gitlab_branch_name'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method gitlab_sync_update" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `gitlab_sync_update`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []
        if 'account_id' in local_var_params and local_var_params['account_id'] is not None:  # noqa: E501
            query_params.append(('account_id', local_var_params['account_id']))  # noqa: E501
        if 'phrase_project_code' in local_var_params and local_var_params['phrase_project_code'] is not None:  # noqa: E501
            query_params.append(('phrase_project_code', local_var_params['phrase_project_code']))  # noqa: E501
        if 'gitlab_project_id' in local_var_params and local_var_params['gitlab_project_id'] is not None:  # noqa: E501
            query_params.append(('gitlab_project_id', local_var_params['gitlab_project_id']))  # noqa: E501
        if 'gitlab_branch_name' in local_var_params and local_var_params['gitlab_branch_name'] is not None:  # noqa: E501
            query_params.append(('gitlab_branch_name', local_var_params['gitlab_branch_name']))  # noqa: E501

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/gitlab_syncs/{id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GitlabSync',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.variables_api import VariablesApi  # noqa: E501
from phrase_api.rest import ApiException


class TestVariablesApi(unittest.TestCase):
    """VariablesApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.variables_api.VariablesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_variable_create(self):
        """Test case for variable_create

        Create a variable  # noqa: E501
        """
        pass

    def test_variable_delete(self):
        """Test case for variable_delete

        Delete a variable  # noqa: E501
        """
        pass

    def test_variable_show(self):
        """Test case for variable_show

        Get a single variable  # noqa: E501
        """
        pass

    def test_variable_update(self):
        """Test case for variable_update

        Update a variable  # noqa: E501
        """
        pass

    def test_variables_list(self):
        """Test case for variables_list

        List variables  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
